@@ -38,7 +38,7 @@ class ETH_IAM_conn:
         self.endpoint_base = endpoint_base
         self.endpoint_base_new = endpoint_base_new
         self.verify_certificates = verify_certificates
-        self.timeout = (1,60)
+        self.timeout = (1, 60)
         # self._get_version()
 
     def get_username(self):
@@ -302,9 +302,7 @@ class ETH_IAM_conn:
         startDate=None,
         endDate=None,
     ):
-        body = {
-            "username": username
-        }
+        body = {"username": username}
         if host:
             body["host"] = host
         if respAdminRole:
@@ -314,6 +312,7 @@ class ETH_IAM_conn:
         if guestTechnicalContact:
             body["guestTechnicalContact"] = guestTechnicalContact
         if notification:
+            notification = format_notification(notification)
             body["notification"] = notification
         if hostOrg:
             body["hostOrg"] = hostOrg
@@ -321,7 +320,7 @@ class ETH_IAM_conn:
             body["startDate"] = startDate
         if endDate:
             body["endDate"] = endDate
-            
+
         guest = Guest(conn=self, data=body, is_new=False)
         guest.save()
         return guest
