@@ -130,19 +130,38 @@ def cli(ctx, host, username, password=None):
 @cli.command("person", help="manage persons")
 @click.argument("person")
 @click.option(
-    "-i",
-    "--info",
+    "-a",
+    "--add-user",
     is_flag=True,
-    default=True,
-    help="all information about the person",
+    help="Add an addtional user (aka persona) to this Person",
 )
+@click.option("-u", "--username", help="Username")
+@click.option("-p", "--init-pw", help="Initial password")
+@click.option("-m", "--mail", help="email address")
+@click.option("-g", "--given-name", help="firstname of this user")
+@click.option("-s", "--surname", help="surname of this user")
+@click.option("-d", "--description", help="Description about the purpose of this user")
 @click.pass_context
-def person(ctx, person, info):
+def person(
+    ctx, person, add_user, username, init_pw, mail, given_name, surname, description
+):
     get_username_password(ctx)
 
     e = login(ctx.obj["username"], ctx.obj["password"], ctx.obj["hostname"])
     person = e.get_person(person)
 
+    if add_user and username:
+        info = {
+            "username": username,
+            "password": init_pw,
+            "description": description,
+            "mail": mail,
+            "firstname": given_name or person["firstname"],
+            "familyname": surname or person["familyname"],
+        }
+        person.new_user(**info)
+        person = e.get_person(person)
+
     print(json.dumps(person.data, indent=4, sort_keys=True))
 
 
@@ -395,6 +414,7 @@ def update_guest(
 @click.option(
     "-e", "--endDate", help="End date of guest (YYYY-MM-DD). Default: today+1 year"
 )
+@click.option("--no-initpw", is_flag=True, help="do not change the initial password")
 @click.pass_context
 def new_guest(
     ctx,
@@ -410,6 +430,7 @@ def new_guest(
     notification,
     startdate,
     enddate,
+    no_initpw,
 ):
     if dateofbirth:
         dateofbirth = to_date(dateofbirth)
@@ -446,18 +467,20 @@ def new_guest(
         click.ClickException(
             "could not set inital password for the guest because the guest has no username."
         )
-    guest_user = iam.get_user(guest_username)
-    try:
-        guest_user.set_password(password=ldap_password, service_name="LDAP")
-        guest_data["init_ldap_password"] = ldap_password
-    except Exception:
-        pass
 
-    try:
-        guest_user.set_password(password=vpn_password, service_name="VPN")
-        guest_data["init_vpn_password"] = vpn_password
-    except Exception as exc:
-        pass
+    if not no_initpw:
+        guest_user = iam.get_user(guest_username)
+        try:
+            guest_user.set_password(password=ldap_password, service_name="LDAP")
+            guest_data["init_ldap_password"] = ldap_password
+        except Exception:
+            pass
+
+        try:
+            guest_user.set_password(password=vpn_password, service_name="VPN")
+            guest_data["init_vpn_password"] = vpn_password
+        except Exception as exc:
+            pass
 
     print(json.dumps(guest_data, indent=4, sort_keys=True))
 
